@@ -2,7 +2,7 @@
 # -*- python -*-
 #BEGIN_LEGAL
 #
-#Copyright (c) 2024 Intel Corporation
+#Copyright (c) 2026 Intel Corporation
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -18,14 +18,11 @@
 #  
 #END_LEGAL
 
-import sys
 import os
 import re
-import shutil
 import copy
 import time
-import types
-import optparse
+from pathlib import Path
 # sys.path is set up by calling script (mfile.py ususally)
 import mbuild 
 import xed_build_common as xbc    
@@ -62,6 +59,7 @@ def mkenv():
                                  die_on_errors=True,
                                  xed_messages=False,
                                  xed_asserts=False,
+                                 api_check=True,
                                  pedantic=True,
                                  clr=False,
                                  use_werror=True,
@@ -89,6 +87,7 @@ def mkenv():
                                  xed_enc2_libs=[],
                                  xed_dir='',
                                  build_cpp_examples=False,
+                                 security_level=2,
                                  set_copyright=False)
 
     env['xed_defaults'] = standard_defaults
@@ -236,7 +235,7 @@ def nchk(env,s):
 def init(env):
     xbc.init(env)
     if nchk(env,'xed_lib_dir'):
-        env['xed_lib_dir'] = '../lib'
+        env['xed_lib_dir'] = str(Path(__file__).parents[1] / 'lib')
 
 
     if nchk(env,'xed_enc2_libs'):
@@ -245,11 +244,11 @@ def init(env):
     if nchk(env,'xed_enc2_libs'):
         # do not build enc2 examples if libraries are missing
         env['enc2'] = False
-        
+    
     if nchk(env,'xed_inc_dir'):
-        env['xed_inc_dir'] = ['../include']
+        env['xed_inc_dir'].append(str(Path(__file__).parents[1] / 'include'))
     if nchk(env,'xed_dir'):
-        env['xed_dir'] = '..'
+        env['xed_dir'] = str(Path(__file__).parents[1])
     env.add_include_dir( env['src_dir'] )  # examples dir
     for inc in  env['xed_inc_dir']: 
         env.add_include_dir( inc )
@@ -261,19 +260,46 @@ def _wk_show_errors_only():
     return True # show errors only.
 
 
-def _add_libxed_rpath(env):
-   """Make example tools refer to the libxed.so from the lib directory"""
-   if env['shared'] and env.on_linux() and not env['android']:
-       env['LINKFLAGS'] += " -Wl,-rpath,'$ORIGIN/../lib'"
+def is_direct_example_build(env: dict) -> bool:
+    """
+    Returns True if this script is being executed directly (not by the XED C library builder).
+
+    The 'examples' target is set by the XED C library builder. If it is not present in env['targets'],
+    this indicates a manual or post-library build phase execution.
+    """
+    try:
+        return 'examples' not in env['targets']
+    except KeyError:
+        return True  # If 'targets' is not defined, assume direct execution
+
+
+def _handle_shared_libxed(env: dict) -> None:
+    """ Support shared libxed build. """   
+    if env['shared'] and env.on_linux() and not env['android']:
+        # Make example tools refer to the libxed.so from the lib directory
+        env['LINKFLAGS'] += " -Wl,-rpath,'$ORIGIN/../lib'"
+        env['LINKFLAGS'] += " -Wl,-rpath,'$ORIGIN/../../lib'" # if executed from "kit/examples/mfile.py"
+    
+    if env.on_windows() and is_direct_example_build(env):
+        # When building the examples manually (i.e., not as part of the XED C library build process),
+        # ensure that xed.dll is available in the build directory so the example executables can locate it.
+        # Since we cannot determine at this stage whether the referenced XED C library is shared or static,
+        # we conservatively copy xed.dll only if it exists at the expected source location and is not 
+        # already present in the build directory.
+        dll_dst_path = Path(env['build_dir'], 'xed.dll')
+        xed_dll = Path(env['xed_lib_dir'], '..', 'bin', 'xed.dll').resolve()
+        if not os.path.exists(dll_dst_path) and os.path.exists(xed_dll):
+            mbuild.msgb("COPY", f"Copying {xed_dll} to {dll_dst_path}")
+            mbuild.copy_file(xed_dll, dll_dst_path)
 
 
 def build_asmparse(env, dag, otherobj):
-    srcs = env.src_dir_join(['xed-asmparse.c'])
+    srcs = env.src_dir_join(['xed-util-asmparse.c'])
     objs = env.compile(dag, srcs)
 
     exe = ex_compile_and_link(env,
                               dag,
-                              env.src_dir_join('xed-asmparse-main.c'),
+                              env.src_dir_join('xed-enc-asmparse.c'),
                               objs + otherobj + [env['link_libxed']])
     return exe
 
@@ -296,8 +322,7 @@ def build_examples(env, work_queue):
 
     link_libxed = env['link_libxed']
     
-    if env['shared']:
-       _add_libxed_rpath(env)
+    _handle_shared_libxed(env)
 
     # C vs C++: env is for C++ and env_c is for C programs.
     if env['compiler'] in  ['gnu','clang']:
@@ -311,16 +336,16 @@ def build_examples(env, work_queue):
           'xed-examples-util.c'])
     if env['decoder']:
         cc_shared_files.extend(env.src_dir_join([ 
-          'xed-dot.c',
-          'xed-dot-prep.c']))
+          'xed-util-dot.c',
+          'xed-util-dot-prep.c']))
         
     if env['encoder']:
-       cc_shared_files += env.src_dir_join([ 'xed-enc-lang.c'])
+       cc_shared_files += env.src_dir_join([ 'xed-util-enc-lang.c'])
     cc_shared_objs  = env.compile( examples_dag, cc_shared_files)
     # the XED command line tool
-    xed_cmdline_files = [ 'xed-disas-raw.c',
+    xed_cmdline_files = [ 'xed-util-disas-raw.c',
                           'avltree.c',
-                          'xed-disas-hex.c',
+                          'xed-util-disas-hex.c',
                           'xed-symbol-table.c']
     if env.on_windows() and env['set_copyright']:
         # AUTOMATICALLY UPDATE YEAR IN THE RC FILE
@@ -334,14 +359,14 @@ def build_examples(env, work_queue):
     if env['decoder']:
 
         if env.on_linux() or env.on_freebsd() or env.on_netbsd():
-            xed_cmdline_files.append('xed-disas-filter.c')
+            xed_cmdline_files.append('xed-util-disas-filter.c')
             xed_cmdline_files.append('xed-nm-symtab.c')
             
         elif env.on_mac():
-            xed_cmdline_files.append('xed-disas-macho.c')
+            xed_cmdline_files.append('xed-util-disas-macho.c')
 
         elif env.on_windows():
-            xed_cmdline_files.append('xed-disas-pecoff.cpp')
+            xed_cmdline_files.append('xed-util-disas-pecoff.cpp')
             if ( env['dbghelp'] and 
                  env['compiler'] == 'ms' and
                  env['msvs_version'] not in ['6','7'] ):
@@ -362,7 +387,7 @@ def build_examples(env, work_queue):
         xbc.cond_add_elf_dwarf(cenv)
         
     if env.on_linux() or env.on_freebsd() or env.on_netbsd():
-        src_elf = env.src_dir_join('xed-disas-elf.c')
+        src_elf = env.src_dir_join('xed-util-disas-elf.c')
         if env['use_elf_dwarf_precompiled']:
             cenv2 = copy.deepcopy(cenv)
             # need to remove -pedantic because of redundant typedef Elf in dwarf header file
@@ -388,33 +413,22 @@ def build_examples(env, work_queue):
     ild_examples = []
     other_c_examples = []
     enc2_examples = []
-    small_examples = ['xed-size.c']
+    small_examples = []
     if env['enc2']:
-        enc2_examples += [ 'xed-enc2-1.c',
-                           'xed-enc2-2.c',
-                           'xed-enc2-3.c' ]
+        enc2_examples += [ 'xed-enc2.c']
     if env['encoder']:
-       small_examples += ['xed-ex5-enc.c']
-       other_c_examples += ['xed-ex3.c']
+       small_examples += ['xed-enc-direct.c']
+       other_c_examples += ['xed-enc.c']
     if env['decoder'] and env['encoder']:
-       other_c_examples += ['xed-ex6.c',
-                            'xed-ex9-patch.c' ]
+       other_c_examples += ['xed-enc-override.c' ]
     if env['decoder']:
-       ild_examples += [ 'xed-ex-ild.c' ]
-       other_c_examples += ['xed-ex1.c',
-                            'xed-ex-ild2.c',
-                            'xed-min.c',
-                            'xed-reps.c',
-                            'xed-ex4.c',
-                            'xed-tester.c',
-                            'xed-dec-print.c',           
-                            'xed-ex-agen.c',
-                            'xed-ex7.c',
-                            'xed-ex8.c',
-                            'xed-ex-cpuid.c',
-                            'xed-tables.c',
-                            'xed-find-special.c',                            
-                            'xed-dll-discovery.c']
+       ild_examples += [ 'xed-dec-ild.c' ]
+       other_c_examples += ['xed-dec.c',
+                            'xed-dec-control.c',
+                            'xed-dec-min.c',
+                            'xed-rep-string.c',     
+                            'xed-dec-agen.c',
+                            'xed-tables.c']
 
     # compile & link other_c_examples
     for example in env.src_dir_join(other_c_examples):
@@ -480,7 +494,7 @@ def examples_work(env):
         if len(env['targets'])<=1:
             xbc.cexit(0)
 
-    mbuild.cmkdir(env['build_dir'])
+        mbuild.cmkdir(env['build_dir'])
     
     work_queue = mbuild.work_queue_t(env['jobs']) 
 
@@ -493,8 +507,6 @@ def examples_work(env):
 
 def execute():
     """Main external entry point for command line invocations"""
-    
-    import mbuild
     env = mkenv()
     # xed_args() is skip-able for remote (import) invocation. The env
     # from mkenv can be updated programmatically. One must call
