@@ -1,6 +1,6 @@
 #BEGIN_LEGAL
 #
-#Copyright (c) 2024 Intel Corporation
+#Copyright (c) 2025 Intel Corporation
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -15,6 +15,13 @@
 #  limitations under the License.
 #  
 #END_LEGAL
+"""
+CPUID record parser and data structures.
+
+This module provides classes for parsing and representing CPUID feature records.
+CPUID records specify processor feature detection through leaf/subleaf/register/bit
+patterns. Used to associate instructions with their required CPUID features.
+"""
 from enum import Enum
 import genutil
 from genutil import die
@@ -228,8 +235,8 @@ class group_record_t:
             loaded = rec.load_from_str(rec_str)
             if not loaded:
                 continue  # Do not append an empty record (Usually "n/a" records)
-            if (self.kind != group_kind_t.AVX10) and ('AVX10' in rec.fname):
-                die(f'Found illegal AVX10 CPUID record ({rec.emit()}) in {self.get_kind_name} group')
+            if (self.kind != group_kind_t.AVX10) and ('AVX10_ENABLED' in rec.fname):
+                die(f'Found illegal AVX10 CPUID record ({rec.emit()}) in {self.get_kind_name()} group')
             self.records.append(rec)
         return self.records_len()
     
@@ -241,6 +248,10 @@ class group_record_t:
             return False
         return len(set(self.get_records()).symmetric_difference(other.get_records())) == 0
     
+    def to_serializable(self) -> dict:
+        ''' Returns a serializable dict representation '''
+        return { self.name : [str(rec) for rec in self.records] }
+
     def __str__(self) -> str:
         """ Overrides the default implementation """
         s = f'Name={self.get_name}, Kind={self.get_kind_name}, ISA-SET={self.isa_set}\n'
