@@ -17,7 +17,14 @@
 #  limitations under the License.
 #  
 #END_LEGAL
+"""
+XED instruction database reader.
 
+This module reads and parses the XED instruction database files (datafiles
+directory) containing instruction encodings, operands, attributes, and other
+metadata. It builds the in-memory representation of all x86 instructions that
+XED can encode and decode. This is the primary input to the XED generator.
+"""
 import sys
 import re
 import collections
@@ -29,6 +36,20 @@ import opnds
 import cpuid_rdr
 import map_info_rdr
 
+from enum import Enum
+
+class Restriction(Enum):
+    OPTIONAL = 0
+    REQUIRED = 1
+    PROHIBITED = 2
+
+    def __str__(self):
+        if self == Restriction.OPTIONAL:
+            # Optional means there's no restriction -> empty restriction string
+            return ''
+        return self.name
+        
+
 
 class inst_t(object):
     def __init__(self):
@@ -62,7 +83,21 @@ class inst_t(object):
             genutil.die("Did not find eosz for {}".format(self.iclass))
         else: #  vex, evex, xop
             return None
-            
+    
+    def get_easz_list(self):
+        if self.space == 'legacy' and hasattr(self,'easz'): 
+            easz_map: dict[str, list[int]] = {
+                'aszall':[16,32,64],
+                'asznot16':[32,64],
+                'asznot64':[16,32],
+                'a16':[16],
+                'a32':[32],
+                'a64':[64],
+                }
+            genutil.cond_die(self.easz not in easz_map, None,
+                             f"Could not handle easz {self.easz} for {self.iclass}")
+            return easz_map[self.easz]
+        return None
 
 class width_info_t(object):
     def __init__(self, name, dtype, widths):
@@ -739,9 +774,16 @@ class xed_reader_t(object):
                 v.is_apx_scc = True
                 v.scc_val: int = get_scc_value(v)
 
-            v.rex2_required: bool = False
-            if 'REX2=1' in v.pattern:
-                v.rex2_required = True
+            is_allowed_rex2 = (v.space == 'legacy' and v.map in [0,1] and v.mode_restriction in ['unspecified', 2])
+
+            v.rex2_restriction = Restriction.PROHIBITED
+            if is_allowed_rex2:  # reject REX2 for non-legacy MAP{0,1} and non-mode 64
+                if 'NOREX2=1' in v.pattern:
+                    v.rex2_restriction = Restriction.PROHIBITED
+                elif 'REX2=1' in v.pattern:
+                    v.rex2_restriction = Restriction.REQUIRED
+                else:
+                    v.rex2_restriction = Restriction.OPTIONAL
 
             v.default_64b = False
             if 'DF64()' in v.pattern or 'CR_WIDTH()' in v.pattern:
