@@ -2,7 +2,7 @@
 # -*- python -*-
 #BEGIN_LEGAL
 #
-#Copyright (c) 2024 Intel Corporation
+#Copyright (c) 2025 Intel Corporation
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -26,7 +26,8 @@ import datetime
 from stat import *
 import argparse
 from collections import defaultdict, Counter
-import subprocess
+import subprocess, shlex
+import platform
 
 XED_ROOT = Path(__file__).parents[1]
 
@@ -61,26 +62,46 @@ def ensure_string(x):
     return x
 
 def run_subprocess(cmd, **kwargs):
-	"""front end to running subprocess"""
-	sub = subprocess.Popen(cmd,
-	                           shell=True,
-	                           stdout=subprocess.PIPE,
-	                           stderr=subprocess.STDOUT,
-	                           **kwargs)
-	lines = sub.stdout.readlines()
-	lines = [ensure_string(x) for x in lines]
-	sub.wait()
-	return sub.returncode, lines
+    """front end to running subprocess safely"""
+
+    sub = subprocess.Popen(
+        cmd,
+        stdout=subprocess.PIPE,
+        stderr=subprocess.STDOUT,
+        shell=False,              # importantly FALSE
+        **kwargs
+    )
+    
+    lines = sub.stdout.readlines()
+    lines = [ensure_string(x) for x in lines]
+    sub.wait()
+    return sub.returncode, lines
+
 
 def run_shell_command(cmd, **kwargs):
-   """INPUT: string with all args. OUTPUT: return the exit status, or die trying..."""
-   try:
-        (returncode, lines) = run_subprocess(cmd, **kwargs)
-        cond_die(returncode, cmd,
-               "Child was terminated by signal {0:d}".format(-returncode), lines)
-        return (returncode, lines)
-   except OSError as e:
-     die("Execution failed: {0}".format(str(e)))
+    """INPUT: string with all args. OUTPUT: return the exit status, or die trying..."""
+    try:
+        if platform.system() == "Windows":
+            # On Windows, pass the raw string to CreateProcess.
+            # No shell is used when shell=False, so no cmd.exe parsing.
+            popen_cmd = cmd
+        else:
+            # On POSIX, convert the string to an argv list.
+            popen_cmd = shlex.split(cmd)
+    
+        returncode, lines = run_subprocess(popen_cmd, **kwargs)
+
+        cond_die(
+            returncode,
+            cmd,
+            f"Child was terminated by signal {-returncode:d}",
+            lines,
+        )
+
+        return returncode, lines
+
+    except OSError as e:
+        die(f"Execution failed: {e}")
 
 def get_mode(fn):
     "get the mode of the file named fn, suitable for os.chmod() or open() calls"
@@ -275,7 +296,7 @@ def replace_headers(files, year=''):
 
 def get_years_from_copyrights(copyrights):
     """Returns the year from a given copyright string. If not found, return None."""
-    regx = '.*copyright.* (\d+\d+)[ ,].*'
+    regx = r'.*copyright.* (\d+\d+)[ ,].*'
     re_obj = re.compile(regx, re.IGNORECASE)
     match = re_obj.search(copyrights)
 
@@ -318,7 +339,7 @@ def check_years(curr_header, file, issues):
 
 def remove_year_from_header(copyright_lines):
     """Removes the line with the year from the legal header."""
-    regx= '.*Copyright \(C\) .* intel corporation.*'
+    regx= r'.*Copyright \(C\) .* intel corporation.*'
     re_obj = re.compile(regx, re.IGNORECASE)
     match = re_obj.search(copyright_lines)
     if match:
@@ -335,8 +356,8 @@ def get_clean_lines(copyright_text):
 
 def get_copyright_from_file(file_content):
     """Extracts the copyright text from the file content."""
-    match_e = re.compile('.*END_LEGAL.*(\n)*', re.IGNORECASE).search(file_content)
-    match_b = re.compile('.*BEGIN_LEGAL.*(\n)*', re.IGNORECASE).search(file_content)
+    match_e = re.compile(r'.*END_LEGAL.*(\n)*', re.IGNORECASE).search(file_content)
+    match_b = re.compile(r'.*BEGIN_LEGAL.*(\n)*', re.IGNORECASE).search(file_content)
     copyright_lines = file_content[match_b.start():match_e.end()]
     return copyright_lines
 
@@ -363,9 +384,9 @@ def check_copyright_text(file_content, file, issues):
 
 def check_header_existence(file_content, file, issues):
     """Checks whether the legal header exists in the file."""
-    start_hdr_pattern = ('.*BEGIN_LEGAL.*(\n)*'
-                   '(:?.+\n)*'
-                   '.*Copyright \(C\) (\d+) intel corporation.*\n')
+    start_hdr_pattern = (r'.*BEGIN_LEGAL.*(\n)*'
+                   r'(:?.+\n)*'
+                   r'.*Copyright \(C\) (\d+) intel corporation.*\n')
     match = re.compile(start_hdr_pattern, re.IGNORECASE).search(file_content)
     if not match:
         issues[file] = 'Intel legal string not found.'
