@@ -1,6 +1,6 @@
-/*BEGIN_LEGAL 
+/* BEGIN_LEGAL 
 
-Copyright (c) 2019 Intel Corporation
+Copyright (c) 2026 Intel Corporation
 
   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
@@ -22,11 +22,16 @@ END_LEGAL */
 
 #include "xed-state.h"
 #include "xed-portability.h"
+#include "xed-util.h"
 
 
 
 
 int   xed_state_print(const xed_state_t* p, char* buf, int buflen)  {
+    if (buflen <= 0)
+        return 0;
+    xed_assert(p != NULL);
+    api_check(buf != NULL);
     int blen = buflen;
     blen = xed_strncpy(buf,"MachineMode: ",blen);
     blen = xed_strncat(buf, xed_machine_mode_enum_t2str(p->mmode),blen);
