@@ -1,6 +1,6 @@
 /* BEGIN_LEGAL 
 
-Copyright (c) 2024 Intel Corporation
+Copyright (c) 2026 Intel Corporation
 
   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
@@ -35,8 +35,18 @@ END_LEGAL */
 
 static void set_has_modrm(xed_decoded_inst_t* d);
 
+static XED_INLINE xed_uint8_t
+decoded_inst_get_byte(const xed_decoded_inst_t* p, xed_uint_t byte_index)
+{
+    xed_assert(p != NULL && p->_byte_array._dec != NULL);
+    /// Read a whole byte from the normal input bytes.
+    xed_uint8_t out = p->_byte_array._dec[byte_index];
+    return out; 
+}
+
 static XED_INLINE void too_short(xed_decoded_inst_t* d)
 {
+    xed_assert(d != NULL);
     xed3_operand_set_out_of_bytes(d, 1);
     if ( xed3_operand_get_max_bytes(d) >= XED_MAX_INSTRUCTION_BYTES)
         xed3_operand_set_error(d,XED_ERROR_INSTR_TOO_LONG);
@@ -46,6 +56,7 @@ static XED_INLINE void too_short(xed_decoded_inst_t* d)
 
 static XED_INLINE void bad_map(xed_decoded_inst_t* d)
 {
+    xed_assert(d != NULL);
     xed3_operand_set_map(d,XED_ILD_MAP_INVALID);
     xed3_operand_set_error(d,XED_ERROR_BAD_MAP);
 }
@@ -54,15 +65,19 @@ static XED_INLINE void bad_map(xed_decoded_inst_t* d)
 // {3,4} if the prefixes are actually used for a Jcc branch.  If 3e is used
 // as a CET no-track indicator, it remains as the value 2.
 static  XED_INLINE void set_hint_3e(xed_decoded_inst_t* d) {
+    xed_assert(d != NULL);
     xed3_operand_set_hint(d,2);
 }
 static  XED_INLINE void set_hint_2e(xed_decoded_inst_t* d) {
+    xed_assert(d != NULL);
     xed3_operand_set_hint(d,1);
 }
 static  XED_INLINE xed_bool_t get_hint_3e(xed_decoded_inst_t const* d) {
+    xed_assert(d != NULL);
     return xed3_operand_get_hint(d)==2;
 }
 static  XED_INLINE void clear_hint(xed_decoded_inst_t* d) {
+    xed_assert(d != NULL);
     xed3_operand_set_hint(d,0);
 }
 
@@ -87,6 +102,7 @@ static void set_prefix_table_bit(xed_uint8_t a)
 {
     xed_uint32_t x = a >> 5;
     xed_uint32_t y = a & 0x1F;
+    xed_assert(x < XED_PREFIX_TABLE_SIZE);
     prefix_table[x] |= (1<<y);
 }
 
@@ -95,6 +111,7 @@ static XED_INLINE xed_uint_t get_prefix_table_bit(xed_uint8_t a)
     // return 1 if the bit is set in the table
     xed_uint32_t x = a >> 5;
     xed_uint32_t y = a & 0x1F;
+    xed_assert(x < XED_PREFIX_TABLE_SIZE);
     return (prefix_table[x] >> y ) & 1;
 }
 
@@ -139,6 +156,7 @@ static void XED_NOINLINE bad_z_aaa(xed_decoded_inst_t* d)
 
 static void prefix_scanner(xed_decoded_inst_t* d)
 {
+    xed_assert(d != NULL);
     xed_uint8_t max_bytes = xed3_operand_get_max_bytes(d);
     unsigned char length = xed_decoded_inst_get_length(d);
     xed_uint8_t nprefixes = 0;
@@ -148,7 +166,7 @@ static void prefix_scanner(xed_decoded_inst_t* d)
 
     while(length < max_bytes)
     {
-        xed_uint8_t b = xed_decoded_inst_get_byte(d, length);
+        xed_uint8_t b = decoded_inst_get_byte(d, length);
         
         // fast check to see if something might be a prefix
         // includes REX prefixes in 32b mode
@@ -374,11 +392,13 @@ typedef union { // C5 payload 1
 static void evex_vex_opcode_scanner(xed_decoded_inst_t* d); //prototype
 
 static void set_vl(xed_decoded_inst_t* d, xed_uint_t vl) {
+    xed_assert(d != NULL);
     xed3_operand_set_vl(d, vl);
 }
 
 static void vex_c4_scanner(xed_decoded_inst_t* d)
 {
+    xed_assert(d != NULL);
     // assumption: length < max_bytes. This is checked in prefix_scanner.
     // c4 is  the byte at 'length'
     xed_uint8_t max_bytes = xed3_operand_get_max_bytes(d);
@@ -386,7 +406,7 @@ static void vex_c4_scanner(xed_decoded_inst_t* d)
     xed_avx_c4_payload1_t c4byte1;    
     if (length+1 < max_bytes)   {
         length++;
-        c4byte1.u32 = xed_decoded_inst_get_byte(d, length);
+        c4byte1.u32 = decoded_inst_get_byte(d, length);
         // in 16/32b modes, the MODRM.MOD field MUST be 0b11
         if (!mode_64b(d) && c4byte1.coarse.rx_inv != 3) {
             // this is not a vex prefix, go to next scanner
@@ -408,7 +428,7 @@ static void vex_c4_scanner(xed_decoded_inst_t* d)
       xed_avx_c4_payload2_t c4byte2;
       xed_uint_t eff_map;
 
-      c4byte2.u32 = xed_decoded_inst_get_byte(d, length+1);
+      c4byte2.u32 = decoded_inst_get_byte(d, length+1);
       length += 2;
       xed_decoded_inst_set_length(d, length); // now point at opcode
 
@@ -449,6 +469,7 @@ static void vex_c4_scanner(xed_decoded_inst_t* d)
 
 static void vex_c5_scanner(xed_decoded_inst_t* d)
 {
+    xed_assert(d != NULL);
     // assumption: length < max_bytes. This is checked in prefix_scanner.
     // c5 is the byte at 'length'
     xed_uint8_t max_bytes = xed3_operand_get_max_bytes(d);
@@ -456,7 +477,7 @@ static void vex_c5_scanner(xed_decoded_inst_t* d)
     xed_avx_c5_payload_t c5byte1;
     if (length + 1 < max_bytes)   {
         length++;
-        c5byte1.u32 = xed_decoded_inst_get_byte(d, length);
+        c5byte1.u32 = decoded_inst_get_byte(d, length);
         // in 16/32b modes, the MODRM.MOD field MUST be 0b11
         if (!mode_64b(d) && c5byte1.coarse.rv3_inv != 3) {
             // this is not a vex prefix, go to next scanner
@@ -515,12 +536,13 @@ static XED_INLINE xed_uint_t get_modrm_reg_field(xed_uint8_t b) {
 
 static void xop_scanner(xed_decoded_inst_t* d)
 {
+    xed_assert(d != NULL);
     // assumption: length < max_bytes. This is checked in prefix_scanner.
     xed_uint8_t max_bytes = xed3_operand_get_max_bytes(d);
     unsigned char length = xed_decoded_inst_get_length(d);
     
     if (length + 1 < max_bytes)   {
-        xed_uint8_t n = xed_decoded_inst_get_byte(d, length+1);
+        xed_uint8_t n = decoded_inst_get_byte(d, length+1);
         /* in all modes, the MODRM.REG field MUST NOT be 0b000.
            mm-rrr-nnn -> mmrr_rnnn
          */
@@ -549,8 +571,8 @@ static void xop_scanner(xed_decoded_inst_t* d)
       xed_avx_c4_payload1_t xop_byte1;
       xed_avx_c4_payload2_t xop_byte2;
       xed_uint8_t map;
-      xop_byte1.u32 = xed_decoded_inst_get_byte(d, length);
-      xop_byte2.u32 = xed_decoded_inst_get_byte(d, length + 1);
+      xop_byte1.u32 = decoded_inst_get_byte(d, length);
+      xop_byte2.u32 = decoded_inst_get_byte(d, length + 1);
       length += 2; /* eat the 8f xop 2B payload */
       xed_decoded_inst_set_length(d, length);
       
@@ -618,6 +640,7 @@ static void xed_ild_chip_init(void) {
 
 static XED_INLINE xed_uint_t chip_could_support_xop(xed_decoded_inst_t* d)
 {
+    xed_assert(d != NULL);
     xed_chip_enum_t chip = xed_decoded_inst_get_input_chip(d);
     if (chip < XED_CHIP_LAST)
         return could_support_xop_instr[chip];
@@ -628,6 +651,7 @@ static XED_INLINE xed_uint_t chip_could_support_xop(xed_decoded_inst_t* d)
 
 static void vex_scanner(xed_decoded_inst_t* d)
 {
+    xed_assert(d != NULL);
     /* this handles the AVX C4/C5 VEX prefixes and also the AMD XOP 0x8F
      * prefix */
     unsigned char length = xed_decoded_inst_get_length(d);
@@ -635,7 +659,7 @@ static void vex_scanner(xed_decoded_inst_t* d)
     
     // assumption: length < max_bytes (checked in prefix_scanner)
     xed_assert(length < xed3_operand_get_max_bytes(d));
-    b = xed_decoded_inst_get_byte(d, length);
+    b = decoded_inst_get_byte(d, length);
 
     if (b == 0xC5) {
         if (!xed3_operand_get_out_of_bytes(d)) 
@@ -658,9 +682,10 @@ static void vex_scanner(xed_decoded_inst_t* d)
 #endif
 
 static void get_next_as_opcode(xed_decoded_inst_t* d) {
+    xed_assert(d != NULL);
     unsigned char length = xed_decoded_inst_get_length(d);
     if (length < xed3_operand_get_max_bytes(d)) {     
-        xed_uint8_t b = xed_decoded_inst_get_byte(d, length);
+        xed_uint8_t b = decoded_inst_get_byte(d, length);
         xed3_operand_set_nominal_opcode(d, b);
         xed3_operand_set_pos_nominal_opcode(d, length);
         xed_decoded_inst_inc_length(d);
@@ -750,12 +775,14 @@ static void init_has_sib_table(void) {
 
 #if defined(XED_SUPPORTS_AVX512)
 static void bad_ll(xed_decoded_inst_t* d) {
+    xed_assert(d != NULL);
     xed3_operand_set_error(d,XED_ERROR_BAD_EVEX_LL);
 }
 
 
 static void bad_ll_check(xed_decoded_inst_t* d)
 {
+    xed_assert(d != NULL);
     if (xed3_operand_get_llrc(d) == 3)  {
         // we have a potentially bad EVEX.LL field.
         if (xed3_operand_get_mod(d) != 3) // memop
@@ -768,6 +795,7 @@ static void bad_ll_check(xed_decoded_inst_t* d)
 
 void xed_modrm_scanner(xed_decoded_inst_t* d)
 {
+    xed_assert(d != NULL);
     xed_uint8_t b;
     xed_uint8_t has_modrm;
     set_has_modrm(d);
@@ -781,7 +809,7 @@ void xed_modrm_scanner(xed_decoded_inst_t* d)
             xed_uint8_t mod;
             xed_uint8_t rm;
 
-            b = xed_decoded_inst_get_byte(d, length);
+            b = decoded_inst_get_byte(d, length);
             xed3_operand_set_modrm_byte(d, b);
             xed3_operand_set_pos_modrm(d, length);
             xed_decoded_inst_inc_length(d); /* eat modrm */
@@ -838,12 +866,12 @@ void xed_modrm_scanner(xed_decoded_inst_t* d)
 
 static void sib_scanner(xed_decoded_inst_t* d)
 {
-    
+  xed_assert(d != NULL);
   if (xed3_operand_get_has_sib(d)) {
       unsigned char length = xed_decoded_inst_get_length(d);
       if (length < xed3_operand_get_max_bytes(d)) {
           xed_uint8_t b;
-          b = xed_decoded_inst_get_byte(d, length); 
+          b = decoded_inst_get_byte(d, length); 
 
           xed3_operand_set_pos_sib(d, length);
           xed3_operand_set_sibscale(d, xed_sib_scale(b));
@@ -865,16 +893,10 @@ static void sib_scanner(xed_decoded_inst_t* d)
   }
 }
 
-/*probably this table should be generated. Leaving it here for now.
-  Maybe in one of the following commits it will be moved to auto generated
-  code.*/
-const xed_ild_l1_func_t* disp_bits_2d[2] = {
-    disp_width_map_legacy_map0,
-    disp_width_map_legacy_map1
-};
 
 static void disp_scanner(xed_decoded_inst_t* d)
 {
+    xed_assert(d != NULL);
     /*                                   0   1  2  3   4  5   6   7   8 */
     static const xed_uint8_t ilog2[] = { 99 , 0, 1, 99, 2, 99, 99, 99, 3 };
 
@@ -884,8 +906,17 @@ static void disp_scanner(xed_decoded_inst_t* d)
     if (yes_no_var == 2) {
         xed_ild_map_enum_t map = (xed_ild_map_enum_t)xed3_operand_get_map(d);
         xed_uint8_t opcode     = xed3_operand_get_nominal_opcode(d);
-        xed_ild_l1_func_t fptr = disp_bits_2d[map][opcode];
-        xed_assert(fptr); // fptr is always valid by design
+        xed_uint_t               vv = xed3_operand_get_vexvalid(d);
+
+        xed_assert(map < XED_MAP_ROW_LIMIT);
+        xed_assert(vv < XED_VEXVALID_LIMIT);
+
+        xed_ild_l1_func_t const* fptr_tbl = xed_ild_disp_width_table[vv][map];
+        xed_ild_l1_func_t      fptr = 0;
+        xed_assert(fptr_tbl); // fptr_tbl guaranteed to be valid by construction
+
+        fptr = fptr_tbl[opcode];
+        xed_assert(fptr); // fptr guaranteed to be valid by construction
         (*fptr)(d);
     }
     /*All other maps should have been set earlier*/
@@ -942,6 +973,7 @@ static void disp_scanner(xed_decoded_inst_t* d)
 
 
 static void set_has_modrm(xed_decoded_inst_t* d) {
+    xed_assert(d != NULL);
     xed_uint_t yes_no_var = xed_ild_get_has_modrm(d);
     if (yes_no_var == 1) {
         xed3_operand_set_has_modrm(d, XED_ILD_HASMODRM_TRUE);
@@ -962,13 +994,8 @@ static void set_has_modrm(xed_decoded_inst_t* d) {
 }
 
 
-
-const xed_ild_l1_func_t* imm_bits_2d[2] = { //FIXME: genericize
-    imm_width_map_legacy_map0,
-    imm_width_map_legacy_map1
-};
-
 static void set_imm_bytes(xed_decoded_inst_t* d) {
+    xed_assert(d != NULL);
     xed_uint8_t imm_bits = xed3_operand_get_imm_width(d);
     if (!imm_bits) {
         xed_uint_t var_or_bytes = xed_ild_get_has_imm(d); 
@@ -978,9 +1005,14 @@ static void set_imm_bytes(xed_decoded_inst_t* d) {
             xed_uint_t               vv = xed3_operand_get_vexvalid(d);
             xed_ild_map_enum_t      map = (xed_ild_map_enum_t)xed3_operand_get_map(d);
             xed_uint8_t          opcode = xed3_operand_get_nominal_opcode(d);
+
+            xed_assert(map < XED_MAP_ROW_LIMIT);
+            xed_assert(vv < XED_VEXVALID_LIMIT);
+
             xed_ild_l1_func_t const* fptr_tbl = xed_ild_imm_width_table[vv][map];
             xed_ild_l1_func_t      fptr = 0;
             xed_assert(fptr_tbl); // fptr_tbl guaranteed to be valid by construction
+
             fptr = fptr_tbl[opcode];
             xed_assert(fptr); // fptr guaranteed to be valid by construction
             (*fptr)(d);
@@ -990,6 +1022,7 @@ static void set_imm_bytes(xed_decoded_inst_t* d) {
 
 ////////////////////////////////////////////////////////////////////////////////
 void xed_set_downstream_info(xed_decoded_inst_t* d, xed_uint_t vv) {
+    xed_assert(d != NULL);
     xed_uint_t mapno = xed3_operand_get_map(d);
 
     // copy the codes from the map_info_t tables for later procsssing
@@ -1001,6 +1034,7 @@ void xed_set_downstream_info(xed_decoded_inst_t* d, xed_uint_t vv) {
 #if defined(XED_AVX)
 static void catch_invalid_rex_or_legacy_prefixes(xed_decoded_inst_t* d)
 {
+    xed_assert(d != NULL);
     // REX, F2, F3, 66 are not allowed before VEX or EVEX prefixes
     if ( mode_64b(d) && xed3_operand_get_rex(d) )
         xed3_operand_set_error(d,XED_ERROR_BAD_REX_PREFIX);
@@ -1013,10 +1047,11 @@ static void catch_invalid_rex_or_legacy_prefixes(xed_decoded_inst_t* d)
 
 static void evex_vex_opcode_scanner(xed_decoded_inst_t* d)
 {
+    xed_assert(d != NULL);
     /* no need to check max_bytes here, it was checked in previous
     scanner */
     unsigned char length = xed_decoded_inst_get_length(d);
-    xed_uint8_t b = xed_decoded_inst_get_byte(d, length);
+    xed_uint8_t b = decoded_inst_get_byte(d, length);
 
     xed3_operand_set_nominal_opcode(d, b);
     xed3_operand_set_pos_nominal_opcode(d, length);
@@ -1029,6 +1064,7 @@ static void evex_vex_opcode_scanner(xed_decoded_inst_t* d)
 // as instructions with the REX2 prefix should be fed to a dedicated REX2 scanner
 static XED_INLINE xed_bool_t opcode_scanner_needed(xed_decoded_inst_t *d)
 {
+    xed_assert(d != NULL);
     // FIXME: Consider skipping error check here — already validated earlier
 #if defined(XED_APX)
     return (xed3_operand_get_error(d) == XED_ERROR_NONE) && (xed3_operand_get_rex2(d) == 0);
@@ -1040,13 +1076,14 @@ static XED_INLINE xed_bool_t opcode_scanner_needed(xed_decoded_inst_t *d)
 
 static void opcode_scanner(xed_decoded_inst_t* d)
 {
+    xed_assert(d != NULL);
     unsigned char length = xed_decoded_inst_get_length(d);
     xed_uint8_t b;
     xed_uint64_t i;
     
     // assumption: length < max_bytes (checked in prefix_scanner)
     xed_assert(length < xed3_operand_get_max_bytes(d));
-    b = xed_decoded_inst_get_byte(d, length);
+    b = decoded_inst_get_byte(d, length);
 
 
     // matching maps vs having a summary of which opcodes are definately map0.
@@ -1070,7 +1107,7 @@ static void opcode_scanner(xed_decoded_inst_t* d)
         return;
     }
 
-    b = xed_decoded_inst_get_byte(d, length); // get next byte
+    b = decoded_inst_get_byte(d, length); // get next byte
 
     //FIXME: could split into two loops and have the map1-like loop first..
 
@@ -1194,6 +1231,7 @@ typedef union{
 static XED_INLINE xed_bool_t 
 decoder_supports_avx512(xed_decoded_inst_t *d)
 {
+    xed_assert(d != NULL);
     if (xed3_operand_get_no_vex(d) || xed3_operand_get_no_evex(d))
         return 0;
     return 1;
@@ -1201,6 +1239,7 @@ decoder_supports_avx512(xed_decoded_inst_t *d)
 
 static XED_INLINE xed_uint8_t set_evex_map(xed_decoded_inst_t *d, xed_evex_payload1_t evex1)
 {
+    xed_assert(d != NULL);
     xed_uint8_t map = evex1.s.map; // 4 bits map
 #if defined(XED_APX)
     if (decoder_supports_apx(d))
@@ -1215,12 +1254,13 @@ static XED_INLINE xed_uint8_t set_evex_map(xed_decoded_inst_t *d, xed_evex_paylo
 
 static void evex_scanner(xed_decoded_inst_t* d)
 {
+    xed_assert(d != NULL);
     unsigned char length = xed_decoded_inst_get_length(d);
     xed_uint8_t b;
 
     // assumption: length < max_bytes (checked in prefix_scanner)
     xed_assert(length < xed3_operand_get_max_bytes(d));
-    b = xed_decoded_inst_get_byte(d, length);
+    b = decoded_inst_get_byte(d, length);
     
     if (b == 0x62)
     {
@@ -1229,7 +1269,7 @@ static void evex_scanner(xed_decoded_inst_t* d)
         xed_uint_t eff_map;
         // check that it is not a BOUND instruction
         if (length + 1 < max_bytes) {
-            evex1.u8 = xed_decoded_inst_get_byte(d, length+1);
+            evex1.u8 = decoded_inst_get_byte(d, length+1);
             if (!mode_64b(d) && evex1.coarse.rx_inv != 3) {
                 /*this is a BOUND instruction */
                 return;
@@ -1258,7 +1298,7 @@ static void evex_scanner(xed_decoded_inst_t* d)
         if (length + 4 < max_bytes) {
             xed_evex_payload2_t evex2;
 
-            evex2.u8 = xed_decoded_inst_get_byte(d, length+2);
+            evex2.u8 = decoded_inst_get_byte(d, length+2);
 
             // above check guarantees that r and x are 1 in 16/32b mode.
             if (mode_64b(d)) {
@@ -1289,7 +1329,7 @@ static void evex_scanner(xed_decoded_inst_t* d)
             if (!xed3_operand_get_error(d))
             {
                 xed_evex_payload3_t evex3;
-                evex3.u8 = xed_decoded_inst_get_byte(d, length+3);
+                evex3.u8 = decoded_inst_get_byte(d, length+3);
 
                 xed3_operand_set_zeroing(d, evex3.s.z);
                 
@@ -1348,6 +1388,7 @@ static void evex_scanner(xed_decoded_inst_t* d)
 
 void late_evex_scanner(xed_decoded_inst_t *d)
 {
+    xed_assert(d != NULL);
     /* Reinterpret the EVEX prefix bits.
      * Due to ModRM.mod dependency and performance in mind, do it as a late scanner */
 #if defined(XED_APX)
@@ -1364,6 +1405,7 @@ void late_evex_scanner(xed_decoded_inst_t *d)
 #endif // XED_APX
     (void) d; // Pacify compiler
 }
+#endif // defined(XED_SUPPORTS_AVX512)
 
 #if defined(XED_APX)
 // process the REX2 prefix if exists.
@@ -1372,12 +1414,13 @@ void late_evex_scanner(xed_decoded_inst_t *d)
 // then scans the instructions' opcode
 static XED_INLINE void rex2_scanner(xed_decoded_inst_t *d)
 {
+    xed_assert(d != NULL);
     xed_uint8_t length = xed_decoded_inst_get_length(d);
     xed_uint8_t b;
     
     // assumption: length < max_bytes (checked in prefix_scanner)
     xed_assert(length < xed3_operand_get_max_bytes(d));
-    b = xed_decoded_inst_get_byte(d, length);
+    b = decoded_inst_get_byte(d, length);
 
     /* REX2 Prefix */
     if (b == 0xD5)
@@ -1400,7 +1443,7 @@ static XED_INLINE void rex2_scanner(xed_decoded_inst_t *d)
             static const xed_ild_map_enum_t rex2_bit_to_map[] = {
                 XED_ILD_LEGACY_MAP0, XED_ILD_LEGACY_MAP1};
             xed_uint8_t map_bit = 0;
-            xed_uint8_t rex2 = xed_decoded_inst_get_byte(d, length + 1);
+            xed_uint8_t rex2 = decoded_inst_get_byte(d, length + 1);
             xed3_operand_set_rex2(d, 1);
 
             map_bit = (rex2>>7) & 1;
@@ -1427,7 +1470,7 @@ static XED_INLINE void rex2_scanner(xed_decoded_inst_t *d)
 
             /* REX2 Opcode scanner */
             length += 2;
-            b = xed_decoded_inst_get_byte(d, length);
+            b = decoded_inst_get_byte(d, length);
             xed3_operand_set_nominal_opcode(d, b);
             xed3_operand_set_pos_nominal_opcode(d, length);
             xed3_operand_set_srm(d, xed_modrm_rm(b));
@@ -1445,6 +1488,7 @@ static XED_INLINE void rex2_scanner(xed_decoded_inst_t *d)
 
 static void imm_scanner(xed_decoded_inst_t* d)
 {
+  xed_assert(d != NULL);
   xed_uint8_t imm_bytes;
   xed_uint8_t imm1_bytes;
   xed_uint8_t max_bytes = xed3_operand_get_max_bytes(d);
@@ -1463,7 +1507,7 @@ static void imm_scanner(xed_decoded_inst_t* d)
           xed3_operand_set_pos_nominal_opcode(d, length);
 
           xed3_operand_set_nominal_opcode(d, 
-                                          xed_decoded_inst_get_byte(d, length));
+                                          decoded_inst_get_byte(d, length));
           /*count the pseudo immediate byte, which is opcode*/
           xed_decoded_inst_inc_length(d); 
           /*imm_bytes == imm_bytes1 == 0 for amd3dnow */
@@ -1554,7 +1598,6 @@ static void imm_scanner(xed_decoded_inst_t* d)
   /* uimm1 is set earlier */
 }
 
-#endif // defined(XED_SUPPORTS_AVX512)
 
 ////////////////////////////////////////////////////////////////////////////////
 
@@ -1587,6 +1630,7 @@ void xed_ild_init(void) {
 void
 xed_instruction_length_decode(xed_decoded_inst_t *ild)
 {
+    xed_assert(ild != NULL);
     prefix_scanner(ild);
 #if defined(XED_AVX) 
     if (xed3_operand_get_out_of_bytes(ild))
@@ -1636,9 +1680,11 @@ xed_instruction_length_decode(xed_decoded_inst_t *ild)
     sib_scanner(ild);
     disp_scanner(ild);
     imm_scanner(ild);
+#if defined(XED_SUPPORTS_AVX512)
     if (xed3_operand_get_vexvalid(ild) == 2) { // EVEX
         late_evex_scanner(ild);
     }
+#endif
 }
 
 #include "xed-chip-modes.h"
@@ -1652,7 +1698,12 @@ xed_ild_decode(xed_decoded_inst_t* xedd,
 {
     xed_uint_t tbytes;
     xed_features_elem_t const *features = 0;
-    xed_chip_enum_t chip = xed_decoded_inst_get_input_chip(xedd);
+    xed_chip_enum_t chip;
+    
+    xed_assert(xedd != NULL);
+    xed_assert(itext != NULL);
+    
+    chip = xed_decoded_inst_get_input_chip(xedd);
     if (chip != XED_CHIP_INVALID)
         features = xed_get_features(chip);
     set_chip_modes(xedd, chip, features); // FIXME: add support for cpuid features
@@ -1698,3 +1749,4 @@ xed_ild_cvt_mode(xed_machine_mode_enum_t mmode) {
     }
     return result;
 }
+
